@@ -44,7 +44,6 @@ OC.L10N.register(
     "An error happened during the creation of the circle" : "サークルの作成中にエラーが発生しました",
     "Download" : "ダウンロード",
     "Rename" : "名前を変更",
-    "Enabled" : "有効",
     "Delete" : "削除",
     "Copied" : "コピーしました",
     "Cannot copy" : "コピーできません",
@@ -63,7 +62,7 @@ OC.L10N.register(
     "Import contacts" : "連絡先のインポート",
     "Import into the {addressbookName} address book" : "アドレス帳 {addressbookName} にインポートします",
     "Select local file" : "ローカルファイルの選択",
-    "Import from Files" : "ファイルからインポート",
+    "Import from files" : "ファイルからインポート ",
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
     "Choose a vCard file to import" : "インポートするvCardファイルを選択",
     "Add new address book" : "新しいアドレス帳を追加する",
@@ -165,7 +164,6 @@ OC.L10N.register(
     "Select chart …" : "組織図を選択...",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
-    "None" : "なし",
     "Add contact in group" : "グループに連絡先を追加",
     "Select option" : "オプションを選択",
     "Unable to create the contact." : "連絡先を追加できません。",
@@ -192,7 +190,6 @@ OC.L10N.register(
     "Not grouped" : "グループ化されていません",
     "Recently contacted" : "最近連絡した",
     "Organization chart" : "組織図",
-    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "サークルを使用すると、Nextcloudで他のユーザーとグループを作成し、それらと共有できます。",
     "Circle" : "サークル",
     "User" : "ユーザー",
     "Group" : "グループ",
@@ -268,6 +265,7 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
+    "None" : "なし",
     "Unknown" : "不明",
     "Time zone" : "時間帯",
     "Spoken languages" : "話せる言語",
