@@ -25,7 +25,6 @@ OC.L10N.register(
     "Contacts settings" : "Kontaktinnstillinger",
     "General settings" : "Generelle innstillinger",
     "Address books" : "Adressebøker",
-    "Download" : "Last ned",
     "Send email" : "Send e-post",
     "Contact groups" : "Kontaktgrupper",
     "Create a new contact group" : "Opprett en ny kontaktgruppe",
@@ -39,8 +38,8 @@ OC.L10N.register(
     "This group already exists" : "Denne gruppen finnes allerede",
     "This circle already exists" : "Denne sirkelen finnes allerede",
     "An error happened during the creation of the circle" : "En feil oppsto under opprettelse av sirkelen",
+    "Download" : "Last ned",
     "Rename" : "Gi nytt navn",
-    "Enabled" : "Aktiver",
     "Delete" : "Slett",
     "Copied" : "Kopiert",
     "Cannot copy" : "Kan ikke kopiere",
@@ -56,7 +55,6 @@ OC.L10N.register(
     "Import contacts" : "Importer kontakter",
     "Import into the {addressbookName} address book" : "Importer til {addressbookName}-adresseboken",
     "Select local file" : "Velg lokal fil",
-    "Import from Files" : "Importer fra Filer",
     "Choose a vCard file to import" : "Velg en vCard-fil å importere",
     "Add new address book" : "Legg til ny adressebok",
     "First name" : "Fornavn",
@@ -78,26 +76,22 @@ OC.L10N.register(
     "Description" : "Beskrivelse",
     "There is no description for this circle" : "Det er ingen beskrivelse av denne sirkelen",
     "Enter a description for the circle" : "Gi en beskrivelse av denne sirkelen",
-    "Add new property" : "Legg til felt",
-    "Choose property type" : "Velg felttype",
+    "Cancel" : "Avbryt",
     "Upload a new picture" : "Last opp et nytt bilde",
     "Choose from Files" : "Velg fra Filer",
     "Download picture" : "Last ned bilde",
     "Delete picture" : "Slett bilde",
     "Invalid image" : "Ugyldig bilde",
-    "Image is too big (max 1MB)." : "Bildet er for stort (opptil 1MB).",
     "Pick an avatar" : "Velg en avatar",
     "No contact selected" : "Ingen kontakt valgt",
     "Select a contact on the list to begin" : "Velg en kontakt fra listen for å begynne",
     "Name" : "Navn",
-    "Company" : "Bedrift",
     "Title" : "Tittel",
+    "Company" : "Bedrift",
     "Clone contact" : "Dupliser kontakt",
     "Generate QR Code" : "Generer QR-kode",
     "Pick an address book" : "Velg en adressebok",
     "Select address book" : "Velg adressebok",
-    "Cancel" : "Avbryt",
-    "This contact is not yet synced. Edit it to save it to the server." : "Denne kontakt er enda ikke synkronisert. Rediger den for å lagre den på serveren.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tillatelse til å redigere denne kontakten.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du prøvde å redigere, har blitt endret. Vennligst oppdater manuelt. Ytterligere endringer vil ikke kunne lagres.",
     "Address book" : "Adressebok",
@@ -151,7 +145,6 @@ OC.L10N.register(
     "Not grouped" : "Ikke gruppert",
     "Recently contacted" : "Nylig kontaktet",
     "Organization chart" : "Organisasjonskart",
-    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "Sirkeler lar deg opprette grupper med andre brukere på en Nextcloud-instans og dele med dem.",
     "Circle" : "Sirkel",
     "User" : "Bruker",
     "Group" : "Gruppe",
@@ -171,11 +164,11 @@ OC.L10N.register(
     "Prevent circle from being a member of another circle" : "Hindre sirkel fra å kunne bli medlem av en annen sirkel",
     "Users" : "Brukere",
     "Email addresses" : "E-postadresser",
-    "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
     "Additional names" : "Ev. mellomnavn",
     "Prefix" : "Prefiks",
     "Suffix" : "Suffiks",
+    "Nickname" : "Kallenavn",
     "Notes" : "Notater",
     "Website" : "Nettsted",
     "Location" : "Sted",
@@ -229,7 +222,6 @@ OC.L10N.register(
     "Time zone" : "Tidssone",
     "Spoken languages" : "Talte språk",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"],
-    "Some circle(s) an error occurred. Check the console for more details." : "En feil har oppstått i en eller flere sirkeler. Sjekk konsollen for mer detaljer.",
     "Unable to create circle {circleName}" : "Kunne ikke opprette sirkelen {displayName}",
     "Unable to delete circle {circleId}" : "Kunne ikke slette sirkelen {circleId}"
 },
