@@ -5,16 +5,16 @@ OC.L10N.register(
     "All contacts" : "全部联系人",
     "Contacts" : "联系人",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
-    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "“日历”是 Nextcloud CalDav 服务器的一个用户界面应用。通过使用此应用，您可以在不同的设备上同步您的活动并进行在线编辑。\n\n* 🚀 **集成了其他的 Nextcloud 应用！** 现在仅仅集成了联系人功能 - 将来将会集成更多。\n* 🌐 **支持WebCal！** 想要在您的日历上看到您最喜爱的球队的比赛时间？没问题！\n* 🙋 **参与人功能！** 邀请他人参与您的活动。\n* 🙈 **我们不是在做无用功！** 基于出色的 [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发.",
+    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud通讯录应用程序是Nextcloud的CardDAV服务器用户界面。您可以轻松使用您的Nextcloud同步各设备上的联系人，并在线上编辑。\n\n* 🚀 **与其他Nextcloud应用程序整合！** 目前有邮件和日历，还会有更多。\n* 🎉 **不会忘记生日！** 您可以将生日与其他重复的活动与您的Nextcloud日历同步。\n* 👥 **分享通讯录！** 您想与您的朋友或同事分享您的联系人吗？没问题！\n* 🙈 **我们不是在重复造轮子！** 基于出色且开源的SabreDAV库。",
     "Copy to full name" : "复制到全名",
     "Omit year" : "忽略年份",
     "Allow updating avatars from social media" : "允许从社交媒体资料更新头像",
     "Please select a circle" : "请选择一个圈子",
     "Loading circle …" : "正在加载圈子 ...",
-    "Your request to join this circle is pending approval" : "你加入这个圈子的请求正在等待批准 ",
-    "You are not a member of {circle}" : "你并非 {circle} 的成员",
+    "Your request to join this circle is pending approval" : "您加入这个圈子的请求正在等待批准",
+    "You are not a member of {circle}" : "您并非 {circle} 的成员",
     "There was an error fetching the member list" : "获取成员列表时发生一个错误",
-    "Loading contacts …" : "加载联系人…",
+    "Loading contacts …" : "正在加载联系人 ...",
     "There are no contacts yet" : "尚无联系人",
     "Create contact" : "创建联系人",
     "There are no contacts in this group" : "该群组中没有联系人",
@@ -27,9 +27,14 @@ OC.L10N.register(
     "Contacts settings" : "联系人设置",
     "General settings" : "一般设置",
     "Update avatars from social media" : "从社交媒体更新头像",
-    "(refreshed once per week)" : "(每周刷新)",
-    "Address books" : "通讯录",
+    "(refreshed once per week)" : "（每周刷新）",
+    "Address books" : "地址簿",
+    "Export" : "导出",
     "Send email" : "发送邮件",
+    "Send email as BCC" : "以抄送模式发送邮件",
+    "Contact groups" : "联系人群组",
+    "Create a new contact group" : "创建联系人群组",
+    "Contact group name" : "联系人群组名称",
     "Circles" : "圈子",
     "Create a new circle" : "新建一个圈子",
     "Show all groups" : "显示所有小组",
@@ -39,9 +44,10 @@ OC.L10N.register(
     "This group already exists" : "该群组已存在",
     "This circle already exists" : "这个圈子已经存在",
     "An error happened during the creation of the circle" : "创建圈子时发生一个错误",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下载",
+    "Show" : "显示",
     "Rename" : "重命名",
-    "Enabled" : "已启用",
     "Delete" : "删除",
     "Copied" : "已复制",
     "Cannot copy" : "无法复制",
@@ -51,8 +57,11 @@ OC.L10N.register(
     "Delete {addressbook}?" : "删除 {addressbook} ？",
     "Deletion of address book was not successful." : "通讯录删除不成功",
     "Renaming of address book was not successful." : "通讯录重命名不成功",
+    "_%n contact_::_%n contacts_" : ["%n 位联系人"],
+    "_%n group_::_%n groups_" : ["%n 个群组"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
-    "Share with users or groups" : "和用户或者组群共享",
+    "Share with users or groups" : "与用户或者群组共享",
+    "Share with users" : "共享给其他用户",
     "No users or groups" : "无用户或群组",
     "can edit" : "可编辑",
     "Unable to delete the share" : "无法删除共享",
@@ -60,7 +69,7 @@ OC.L10N.register(
     "Import contacts" : "导入联系人",
     "Import into the {addressbookName} address book" : "导入 {addressbookName} 通讯录",
     "Select local file" : "选择本地文件",
-    "Import from Files" : "从文件导入",
+    "Import from files" : "从文件导入",
     "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Add new address book" : "添加新通讯录",
@@ -77,11 +86,11 @@ OC.L10N.register(
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Password protection" : "密码保护",
     "Enforce password protection on files shared to this circle" : "对分享到该圈子中的文件强制使用密码保护",
-    "Use a unique password for all shares to this circle" : "对分享到该圈子中的文件使用独一无二的密码",
-    "Unique password …" : "独一无二的密码 …",
+    "Use a unique password for all shares to this circle" : "对分享到该圈子中的文件使用独立密码",
+    "Unique password …" : "独立密码 ...",
     "Save" : "保存",
-    "Change unique password" : "修改独一无二的密码",
-    "Failed to save password. Please try again later." : "保存密码失败。请稍后重试。",
+    "Change unique password" : "修改独立密码",
+    "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
     "Circle name" : "圈子名称",
     "Circle owned by {owner}" : "圈子所有者为  {owner}",
     "Request to join" : "请求加入",
@@ -90,13 +99,18 @@ OC.L10N.register(
     "Enter a description for the circle" : "为这个圈子输入一个描述",
     "An error happened during description sync" : "描述同步期间发生一个错误",
     "An error happened during name sync" : "名称同步期间发生了一个错误",
+    "Add more info" : "添加更多信息",
+    "More fields" : "更多领域",
+    "Crop contact photo" : "裁剪联系人照片",
     "Cancel" : "取消",
     "Upload a new picture" : "上传一张新的图片",
     "Choose from Files" : "从文件中选择",
     "Get from " : "获取自",
     "Download picture" : "下载图片",
     "Delete picture" : "删除图片",
+    "Please select a valid format" : "请选择有效格式",
     "Invalid image" : "无效的图像",
+    "Error cropping picture" : "裁剪照片时发生错误",
     "Pick an avatar" : "选择一个头像",
     "Error while processing the picture." : "处理图片时出错。",
     "Avatar downloaded from social network" : "已从社交媒体下载头像",
@@ -107,7 +121,8 @@ OC.L10N.register(
     "Name" : "名称",
     "Title" : "头衔",
     "Company" : "公司",
-    "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人已损坏但接收到了一个修复。请查看内容并点击这里以保存它。",
+    "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人资料损坏但已被修复。请查看内容并点击这里以保存它。",
+    "Edit" : "编辑",
     "Clone contact" : "克隆联系人",
     "Generate QR Code" : "生成二维码",
     "Contact vCard as QR code" : "联系人名片作为二维码",
@@ -118,12 +133,15 @@ OC.L10N.register(
     "Address book" : "地址簿",
     "Add contact to Birthday Calendar" : "添加联系人到生日日历",
     "Exclude contact from Birthday Calendar" : "从生日日历中排除联系人",
+    "{title} at {organization}" : "{organization} 的 {title}",
     "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
-    "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器取回联系人，请检查你的网络连接。",
+    "The contact does not exist on the server anymore." : "服务器上不再存在此联系人。",
+    "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器获取联系人，请检查您的网络连接。",
     "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
     "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
-    "Search contacts …" : "搜索联系人 …",
+    "Unable to update contact" : "无法更新联系人",
+    "Search contacts …" : "搜索联系人 ...",
     "Add to {group}" : "添加到 {group}",
     "Remove {type}" : "移除 {type}",
     "Search {types}" : "搜索 {types}",
@@ -133,12 +151,13 @@ OC.L10N.register(
     "Add {type}" : "添加  {type}",
     "New circle name" : "新的圈子名称",
     "Personal circle" : "个人圈子",
-    "This circle will only be visible to you. Other members will not be able to see or use it." : "这个圈子仅对你可见。其他成员无法看见或使用它",
+    "This circle will only be visible to you. Other members will not be able to see or use it." : "这个圈子仅对您可见，其他成员无法看见或使用它。",
     "Local circle" : "本地圈子",
-    "This circle will not be shared with the other instances of the global scale" : "这个圈子不会与 GlobalScale 的其他实例共享 ",
+    "This circle will not be shared with the other instances of the global scale" : "这个圈子不会与全球范围内的其他实例共享 ",
     "Create circle" : "创建圈子",
-    "Loading members list …" : "加载成员列表中 ...",
+    "Loading members list …" : "正在加载成员列表 ...",
     "The list of members is only visible to members of this circle" : "成员列表仅对这个圈子的成员可见",
+    "You currently have no access to the member list" : "您目前无法访问成员列表",
     "Add members" : "添加成员",
     "Show circle details" : "显示圈子详情",
     "Add to {circle}" : "添加到 {circle}",
@@ -158,12 +177,13 @@ OC.L10N.register(
     "Could not change the member level to {level}" : "无法更改成员级别到 {level}",
     "Could not accept membership request" : "无法接受成员身份请求",
     "Chart" : "图表",
-    "Select chart …" : "选择图表 …",
+    "Select chart …" : "选择图表 ...",
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
-    "None" : "无",
     "Add contact in group" : "添加联系人到群组",
+    "none" : "无",
     "Select option" : "选择选项",
+    "Add property of this type" : "为此类型添加属性",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
     "Group {group} not found" : "未找到小组 {group} ",
@@ -176,11 +196,11 @@ OC.L10N.register(
     "Import" : "导入",
     "Could not copy" : "无法复制",
     "Join circle" : "加入圈子",
-    "You are about to leave {circle}.\nAre you sure?" : "你即将离开 {circle}\n确定吗？",
-    "Please confirm circle leave" : "请确认退圈",
+    "You are about to leave {circle}.\nAre you sure?" : "您即将离开 {circle}\n确定吗？",
+    "Please confirm circle leave" : "请确认离开此圈子",
     "Could not leave the circle {displayName}" : "无法离开圈子 {displayName}",
     "Unable to join the circle" : "无法加入这个圈子",
-    "You are about to delete {circle}.\nAre you sure?" : "你即将删除 {circle}\n确定吗？",
+    "You are about to delete {circle}.\nAre you sure?" : "您即将删除 {circle}\n确定吗？",
     "Please confirm circle deletion" : "请确认删除操作",
     "Unable to delete the circle" : "无法删除圈子",
     "Link copied to the clipboard" : "链接已复制到剪贴板",
@@ -188,26 +208,26 @@ OC.L10N.register(
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
-    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "Circles 允许你在 Nextcloud 实例上与其他用户创建组并与他们分享。",
     "Circle" : "圈子",
     "User" : "用户",
     "Group" : "小组",
     "Email" : "电子邮件",
-    "Contact" : "联系",
+    "Contact" : "联系人",
     "Member" : "成员",
-    "Moderator" : "版主",
+    "Moderator" : "主持人",
     "Admin" : "管理员",
     "Owner" : "所有者",
     "Invites" : "邀请",
     "Anyone can request membership" : "任何人均可请求成员资格",
     "Members need to accept invitation" : "成员需要接受邀请",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成员资格必须由一名版主进行确认/接受 (需要开放)",
-    "Members can also invite" : "成员也可以进行邀请",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成员资格必须由一名主持人确认/接受（必须为开放圈子）",
+    "Members can also invite" : "成员也可以邀请",
     "Visibility" : "可见性",
     "Visible to everyone" : "对所有人可见",
     "Circle membership" : "圈子成员资格",
     "Prevent circle from being a member of another circle" : "防止圈子成为另一个圈子的成员",
     "Users" : "用户",
+    "Email addresses" : "电子邮件地址",
     "Detailed name" : "全名",
     "Additional names" : "其他名称",
     "Prefix" : "前缀",
@@ -263,10 +283,12 @@ OC.L10N.register(
     "Gender" : "性别",
     "Female" : "女性",
     "Male" : "男性",
+    "None" : "无",
     "Unknown" : "未知",
     "Time zone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "An error has occurred in circle(s). Check the console for more details." : "圈子中出现错误。请查看控制台以获取详细信息。",
     "Unable to create circle {circleName}" : "无法创建圈子 {circleName}",
     "Unable to delete circle {circleId}" : "无法删除圈子 {circleId}",
     "Unable to delete contact" : "无法删除联系人"
